﻿## Options
##
## This file contains some of the options that can be changed to customize
## your Ren'Py game. It only contains the most common options... there
## is quite a bit more customization you can do.
##
## Lines beginning with two '#' marks are comments, and you shouldn't
## uncomment them. Lines beginning with a single '#' mark are
## commented-out code, and you may want to uncomment them when
## appropriate.

init -1:
    python hide:
        
        config.developer = True
        config.log = 'Eidolon_log.txt'

        config.screen_width = 800
        config.screen_height = 600

        config.window_title = u"Eidolon -- A Ren'Py Game"
        
        config.archives = [ 'data' ]
        config.window_icon = 'icon32.png'
        
        ## Using the default "Colorblind" scheme, because it works so well.
        
        theme.roundrect(

            ## The color of an idle widget face.
            widget = "#898989",

            ## The color of a focused widget face.
            widget_hover = "#464646",

            ## The color of the text in a widget.
            widget_text = "#CCCCCC",

            ## The color of the text in a selected widget. (For
            ## example, the current value of a preference.)
            widget_selected = "#F2F2F2",

            ## The color of a disabled widget face. 
            disabled = "#898989",

            ## The color of disabled widget text.
            disabled_text = "#666666",

            ## The color of informational labels.
            label = "#c2c2c2",

            ## The color of a frame containing widgets.
            frame = "#252525",

            ## If this is True, in-game menus are placed in the center
            ## the screen. If False, they are placed inside a window
            ## at the bottom of the screen.
            button_menu = True,

            ## If this is True, the in-game window is rounded. If False,
            ## the in-game window is square.
            rounded_window = False,

            ## The background of the main menu. This can be a color
            ## beginning with '#', or an image filename. The latter
            ## should take up the full height and width of the screen.
            mm_root = "#393939",

            ## The background of the game menu. This can be a color
            ## beginning with '#', or an image filename. The latter
            ## should take up the full height and width of the screen.
            gm_root = "#393939",

            ## And we're done with the theme. The theme will customize
            ## various styles, so if we want to change them, we should
            ## do so below.            
            )
            
        # Change some styles, to add images in the background of the menus and windows.
        ## The main menu background should be the spiderwebs with a flash of the male and female leads across it.
        ## First, fade in the title at the bottom left, then fade in the girl's face in the large spiderweb, then fade in
        ## the guy's face in the small spider web (or also in the large spiderweb).
        style.mm_root_window.background = Animation(
                                "menuscreen_01.png", 5.50,
                                "menuscreen_03.png", 0.10,
                                "menuscreen_04.png", 0.10,
                                "menuscreen_05.png", 0.10,
                                "menuscreen_07.png", 0.15,
                                "menuscreen_08.png", 0.10,
                                "menuscreen_09.png", 0.10,
                                "menuscreen_10.png", 0.10,
                                "menuscreen_11.png", 0.10,
                                "menuscreen_01.png", 5.50,
                                )
        style.gm_root_window.background = Image("savescreen.png")


        #########################################
        ## These settings let you customize the window containing the
        ## dialogue and narration, by replacing it with an image.

        ## The background of the window. In a Frame, the two numbers
        ## are the size of the left/right and top/bottom borders,
        ## respectively.

        # style.window.background = Frame("frame.png", 12, 12)
        
        ## Margin is space surrounding the window, where the background
        ## is not drawn.

        # style.window.left_margin = 6
        # style.window.right_margin = 6
        # style.window.top_margin = 6
        # style.window.bottom_margin = 6
        
        ## Padding is space inside the window, where the background is
        ## drawn.

        # style.window.left_padding = 6
        # style.window.right_padding = 6
        # style.window.top_padding = 6
        # style.window.bottom_padding = 6

        ## This is the minimum height of the window, including the margins
        ## and padding.

        # style.window.yminimum = 250


        #########################################
        ## This lets you change the placement of the main menu.
        
        ## The way placement works is that we find an anchor point
        ## inside a displayable, and a position (pos) point on the
        ## screen. We then place the displayable so the two points are
        ## at the same place.

        ## An anchor/pos can be given as an integer or a floating point
        ## number. If an integer, the number is interpreted as a number
        ## of pixels from the upper-left corner. If a floating point,
        ## the number is interpreted as a fraction of the size of the
        ## displayable or screen.

        # style.mm_menu_frame.xpos = 0.5
        # style.mm_menu_frame.xanchor = 0.5
        # style.mm_menu_frame.ypos = 0.75
        # style.mm_menu_frame.yanchor = 0.5

        #########################################
        ## These settings let you change some of the sounds that are used by
        ## Ren'Py.

        ## Set this to False if the game does not have any sound effects.

        config.has_sound = True

        ## Set this to False if the game does not have any music.

        config.has_music = True

        ## Set this to False if the game does not have voicing.

        config.has_voice = False

        ## Sounds that are used when button and imagemaps are clicked.

        # style.button.activate_sound = "click.wav"
        # style.imagemap.activate_sound = "click.wav"

        ## Sounds that are used when entering and exiting the game menu.

        # config.enter_sound = "click.wav"
        # config.exit_sound = "click.wav"

        ## A sample sound that can be played to check the sound volume.

        # config.sample_sound = "click.wav"

        ## Music that is played while the user is at the main menu.

        # config.main_menu_music = "main_menu_theme.ogg"

        
        #########################################
        ## Miscellaneous customizations

        ## These let you change the transitions that are used when entering
        ## and exiting the game menu.

        config.enter_transition = dissolve
        config.exit_transition = dissolve

        ## Note: The following two options are only evaluated the first time
        ## a game is run. To have them run a second time, delete
        ## game/saves/persistent
        
        ## Should we start in fullscreen mode?
        config.default_fullscreen = False

        ## The default text speed in characters per second. 0 is infinite.
        config.default_text_cps = 0

        ## say window styles to make subtitles less bulky
        style.input_window.take(style.say_window)

        style.say_window.background = Solid((0, 0, 0, 150))
        style.say_window.ypos = 0.1
        style.say_window.yanchor = 0.1
        
        ## debug window style
        style.create('debug_window', 'say_window')

        style.debug_window.background = Solid((119, 2, 2, 150))

        ## menu window styles to approximate a keyword menu
        style.menu_window.xanchor = 0.97
        style.menu_window.xpos = 0.97
        style.menu_window.yanchor = 0.1
        style.menu_window.ypos = 0.1
        
        style.menu_window.ypadding = 15
        style.menu_window.xpadding = 15
        # style.menu_window.yminimum = 227
        style.menu_window.xminimum = 200
        # style.menu_window.xfill = True
        style.menu_window.background = Frame("frame.png", 20, 20)
        # style.menu_window.background = Solid((0,0,0, 200))
        
        style.menu_choice_button.xminimum = 180
        # style.menu_choice_button.background = Solid((255, 254, 242, 255))
        
        style.create('navigation_panel', 'window')
        style.navigation_panel.xanchor=0.05
        style.navigation_panel.xpos=0.05
        style.navigation_panel.yanchor=0.95
        style.navigation_panel.ypos=0.95
        
        ## text styling
        style.default.font = "fonts/Berolina.ttf"
        style.default.size = 22

        style.centered_text.font = "fonts/ASENT___.ttf"
        style.centered_text.size = 38
        
        style.say_dialogue.font = "fonts/BastardusSans.ttf"
        style.say_dialogue.size = 18
        
        style.say_thought.font = "fonts/BastardusSans.ttf"
        style.say_thought.size = 18
        
        ## nvl mode styling
        style.nvl_window.ypos = 0.2
        style.nvl_window.xmargin = 185
        style.window.xminimum = 350
        style.nvl_window.yminimum = 350
        style.nvl_window.xpadding = 15
        style.nvl_window.top_padding = 15
        style.nvl_window.bottom_padding = 15
    
        style.nvl_window.xfill = True
        style.nvl_vbox.box_spacing = 10
        
        style.nvl_dialogue.text_align = 0.5
